@@ -36,8 +36,6 @@ struct _NautilusTagManager
 
 G_DEFINE_TYPE (NautilusTagManager, nautilus_tag_manager, G_TYPE_OBJECT);
 
-static NautilusTagManager *tag_manager = NULL;
-
 typedef enum
 {
     GET_STARRED_FILES,
@@ -91,7 +89,7 @@ nautilus_tag_manager_file_with_id_changed_url (GHashTable  *hash_table,
     return NULL;
 }
 
-void
+static void
 destroy_insert_task_data (gpointer data)
 {
     InsertTaskData *task_data;
@@ -680,7 +678,7 @@ nautilus_tag_manager_unstar_files (NautilusTagManager  *self,
     g_string_free (query, TRUE);
 }
 
-void
+static void
 on_tracker_notifier_events (TrackerNotifier *notifier,
                             GPtrArray       *events,
                             gpointer         user_data)
@@ -841,8 +839,11 @@ nautilus_tag_manager_class_init (NautilusTagManagerClass *klass)
                                              G_TYPE_POINTER);
 }
 
-NautilusTagManager *nautilus_tag_manager_get ()
+NautilusTagManager *
+nautilus_tag_manager_get (void)
 {
+    static NautilusTagManager *tag_manager = NULL;
+
     if (tag_manager != NULL)
     {
         return g_object_ref (tag_manager);
@@ -854,20 +855,21 @@ NautilusTagManager *nautilus_tag_manager_get ()
     return tag_manager;
 }
 
-void nautilus_tag_manager_set_cancellable (NautilusTagManager *tag_manager,
-                                           GCancellable       *cancellable)
+void
+nautilus_tag_manager_set_cancellable (NautilusTagManager *self,
+                                      GCancellable       *cancellable)
 {
-    nautilus_tag_manager_query_starred_files (tag_manager, cancellable);
+    nautilus_tag_manager_query_starred_files (self, cancellable);
 
-    tag_manager->notifier = tracker_notifier_new (NULL,
-                                                  TRACKER_NOTIFIER_FLAG_QUERY_LOCATION,
-                                                  cancellable,
-                                                  &tag_manager->notifier_error);
+    self->notifier = tracker_notifier_new (NULL,
+                                           TRACKER_NOTIFIER_FLAG_QUERY_LOCATION,
+                                           cancellable,
+                                           &self->notifier_error);
 
-    g_signal_connect (tag_manager->notifier,
+    g_signal_connect (self->notifier,
                       "events",
                       G_CALLBACK (on_tracker_notifier_events),
-                      tag_manager);
+                      self);
 }
 
 static void
